Web Applications often have predictable usernames and weak password policies set.
This can easily allow an attacker to gain unauthorized access into the application
by guessing the credentials used for authentication.

It was possible to guess and
gain a set a valid credentials for the application is scope.